@@ -19,6 +19,7 @@ import os
 import re
 
 from calculate.core.datavars import DataVarsCore
+from calculate.lib.utils.files import readFile
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -120,11 +121,11 @@ def get_CRL(path_to_cert):
     glob_root_cert = clVars.Get('cl_glob_root_cert')
 
     if os.path.exists(user_root_cert):
-        user_ca_certs = open(user_root_cert, 'r').read()
+        user_ca_certs = readFile(user_root_cert)
     else:
         user_ca_certs = ''
     if os.path.exists(glob_root_cert):
-        glob_ca_certs = open(glob_root_cert, 'r').read()
+        glob_ca_certs = readFile(glob_root_cert)
     else:
         glob_ca_certs = ''
 
@@ -172,7 +173,7 @@ def get_CRL(path_to_cert):
                         # os.unlink(CRL_file)
                         continue
                     if os.path.exists(CRL_file):
-                        if open(CRL_file, 'r').read() == new_crl:
+                        if readFile(CRL_file) == new_crl:
                             continue
 
                     with open(CRL_file, 'w') as fd:
@@ -255,7 +256,7 @@ def rm_ca_from_trusted(ca_cert):
             words = line.split()
             if words[0] == md5sum:
                 filename = os.path.join(user_ca_dir, words[1])
-                if ca_cert == open(filename, 'r').read():
+                if ca_cert == readFile(filename):
                     os.unlink(filename)
                 else:
                     newfile += (line + '\n')
@@ -270,7 +271,7 @@ def rm_ca_from_trusted(ca_cert):
     p = re.compile('[-]+[\w ]+[-]+\n+[\w\n\+\\=/]+[-]+[\w ]+[-]+\n?')
 
     # open, write and split user ca certificates
-    user_ca_certs = open(user_ca_db, 'r').read()
+    user_ca_certs = readFile(user_ca_db)
     user_ca_certs_list = p.findall(user_ca_certs)
 
     if ca_cert in user_ca_certs_list:
@@ -282,15 +283,14 @@ def rm_ca_from_trusted(ca_cert):
                 print _("CA certificate deleted from the user's trusted "
                         "certificates list")
 
-        fd = open(user_ca_db, 'w')
-        for cert in new_user_ca_certs:
-            fd.write(cert)
-        fd.close()
+        with open(user_ca_db, 'w') as fd:
+            for cert in new_user_ca_certs:
+                fd.write(cert)
 
     if not os.path.exists(system_ca_db):
-        open(system_ca_db, 'w')
+        open(system_ca_db, 'w').close()
 
-    system_ca_certs = open(system_ca_db, 'r').read()
+    system_ca_certs = readFile(system_ca_db)
     system_ca_certs_list = p.findall(system_ca_certs)
 
     if ca_cert in system_ca_certs_list:
