@@ -17,8 +17,9 @@
 import urllib2 as u2
 import os
 import sys
-from sudsds.transport.http import HttpTransport
-import httplib
+# from sudsds.transport.http import HttpTransport
+from suds.transport.http import HttpTransport
+import httplib #http.client in python3
 from httplib import HTTPConnection
 import socket
 import ssl
@@ -26,7 +27,8 @@ import hashlib
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.datavars import DataVars
 from calculate.lib.utils.files import readFile
-from sudsds.client import Client
+# from sudsds.client import Client
+from suds.client import Client
 from cert_verify import verify, get_CRL
 
 if hasattr(ssl, "PROTOCOL_TLSv1_2"):
