@@ -26,15 +26,16 @@ from calculate.lib.utils.tools import ignore
 class CoreWsdl(CoreServiceInterface):
     sid_pid_locker = Lock()
 
-    def del_sid_pid(self, sid):
+    @staticmethod
+    def del_sid_pid(cls, sid):
         # delete conformity pid and sid of sid_pid file
-        if not os.path.exists(self.sids_pids):
-            temp = open(self.sids_pids, 'w')
+        if not os.path.exists(cls.sids_pids):
+            temp = open(cls.sids_pids, 'w')
             temp.close()
-        sid_pid_t = self.sids_pids + '_temp'
+        sid_pid_t = cls.sids_pids + '_temp'
 
-        with self.sid_pid_locker:
-            fd = open(self.sids_pids, 'r')
+        with cls.sid_pid_locker:
+            fd = open(cls.sids_pids, 'r')
             ft = open(sid_pid_t, 'w')
             while 1:
                 try:
@@ -46,13 +47,13 @@ class CoreWsdl(CoreServiceInterface):
                     pickle.dump(list_sid, ft)
                 else:
                     # end process pid = list_sid[1]
-                    self.serv_pid_kill(list_sid[1], sid)
+                    cls.serv_pid_kill(list_sid[1], sid)
                     # delete this of process file
-                    while self.glob_process_dict[list_sid[1]]['status'] == 1:
+                    while cls.glob_process_dict[list_sid[1]]['status'] == 1:
                         time.sleep(0.1)
-                    self.del_pid(list_sid[1])
+                    cls.del_pid(cls, list_sid[1])
                     # delete process file
-                    rm_fn = path.join(self.pids, "%d.pid" % list_sid[1])
+                    rm_fn = path.join(cls.pids, "%d.pid" % list_sid[1])
                     if path.exists(rm_fn):
                         with ignore(OSError):
                             os.unlink(rm_fn)
@@ -60,28 +61,29 @@ class CoreWsdl(CoreServiceInterface):
             ft.close()
 
             ft = open(sid_pid_t, 'rb')
-            fd = open(self.sids_pids, 'wb')
+            fd = open(cls.sids_pids, 'wb')
             ft.seek(0)
             fd.write(ft.read())
             ft.close()
             fd.close()
 
             # delete sid file
-            sid_file = os.path.join(self.sids, "%d.sid" % sid)
+            sid_file = os.path.join(cls.sids, "%d.sid" % sid)
             if os.path.exists(sid_file):
                 os.unlink(sid_file)
             os.unlink(sid_pid_t)
         return 0
 
-    def del_pid_from_sid_pid(self, pid):
+    @staticmethod
+    def del_pid_from_sid_pid(cls, pid):
         # delete conformity pid and sid of sid_pid file
-        if not os.path.exists(self.sids_pids):
-            temp = open(self.sids_pids, 'w')
+        if not os.path.exists(cls.sids_pids):
+            temp = open(cls.sids_pids, 'w')
             temp.close()
-        sid_pid_t = self.sids_pids + '_temp'
+        sid_pid_t = cls.sids_pids + '_temp'
 
-        with self.sid_pid_locker:
-            fd = open(self.sids_pids, 'r')
+        with cls.sid_pid_locker:
+            fd = open(cls.sids_pids, 'r')
             ft = open(sid_pid_t, 'w')
             while 1:
                 try:
@@ -95,7 +97,7 @@ class CoreWsdl(CoreServiceInterface):
             ft.close()
 
             ft = open(sid_pid_t, 'rb')
-            fd = open(self.sids_pids, 'wb')
+            fd = open(cls.sids_pids, 'wb')
             ft.seek(0)
             fd.write(ft.read())
             ft.close()
@@ -105,13 +107,14 @@ class CoreWsdl(CoreServiceInterface):
             os.unlink(sid_pid_t)
         return 0
 
-    def find_sid_pid_file(self, sid):
+    @staticmethod
+    def find_sid_pid_file(cls, sid):
         results = []
-        with self.sid_pid_locker:
-            if not os.path.exists(self.sids_pids):
-                temp = open(self.sids_pids, 'w')
+        with cls.sid_pid_locker:
+            if not os.path.exists(cls.sids_pids):
+                temp = open(cls.sids_pids, 'w')
                 temp.close()
-            fd = open(self.sids_pids, 'r')
+            fd = open(cls.sids_pids, 'r')
             while 1:
                 try:
                     # read out on 1 record
@@ -125,13 +128,14 @@ class CoreWsdl(CoreServiceInterface):
             fd.close()
         return results
 
-    def serv_pid_info(self, sid, pid):
+    @staticmethod
+    def serv_pid_info(cls, sid, pid):
         f = 0
         results = []
         # Check pid presence and conformity sid
 
-        with self.sid_pid_locker:
-            fd = open(self.sids_pids, 'r')
+        with cls.sid_pid_locker:
+            fd = open(cls.sids_pids, 'r')
             while 1:
                 try:
                     # read out on 1 record
@@ -145,29 +149,30 @@ class CoreWsdl(CoreServiceInterface):
 
             # Get information about pid
             if f == 1:
-                _t = self.glob_process_dict[pid]
+                _t = cls.glob_process_dict[pid]
                 # process id
                 results.append(str(pid))
                 # current state
-                results.append(str(self.glob_process_dict[pid]['status']))
+                results.append(str(cls.glob_process_dict[pid]['status']))
                 # start time
-                results.append(str(self.glob_process_dict[pid]['time']))
+                results.append(str(cls.glob_process_dict[pid]['time']))
                 # process (function) name
-                results.append(str(self.glob_process_dict[pid]['name']))
+                results.append(str(cls.glob_process_dict[pid]['name']))
                 # process soap method name
-                results.append(str(self.glob_process_dict[pid]['method_name']))
+                results.append(str(cls.glob_process_dict[pid]['method_name']))
         return results
 
-    def add_sid_pid(self, sid, pid):
+    @staticmethod
+    def add_sid_pid(cls, sid, pid):
         """
         add conformity pid and sin in sid_pid file
         """
-        with self.sid_pid_locker:
-            if not os.path.exists(self.sids_pids):
-                with open(self.sids_pids, 'w'):
+        with cls.sid_pid_locker:
+            if not os.path.exists(cls.sids_pids):
+                with open(cls.sids_pids, 'w'):
                     pass
             try:
-                with open(self.sids_pids, 'a') as fd:
+                with open(cls.sids_pids, 'a') as fd:
                     pickle.dump([sid, pid], fd)
                 return 0
             except (OSError, IOError, KeyError, EOFError):
